@@ -32,22 +32,21 @@ but also for any :class:`Seq`.
 from __future__ import annotations
 
 from ._base import BiglistBase, FileReader, FileSeq
-from ._biglist import Biglist, BiglistFileReader, BiglistFileSeq
+from ._biglist import Biglist, BiglistFileReader, BiglistFileSeq, Multiplexer
 from ._parquet import (
     ParquetBatchData,
     ParquetBiglist,
     ParquetFileReader,
     ParquetFileSeq,
     read_parquet_file,
-    write_parquet_file,
 )
-from ._util import Chain, Seq, Slicer
+from ._util import (
+    Chain,
+    Seq,
+    Slicer,
+    write_arrays_to_parquet,
+    write_parquet_file,
+    write_pylist_to_parquet,
+)
 
-__version__ = "0.7.6"
-
-# Back compat; will be removed >=0.7.6
-FileView = FileReader
-BiglistFileView = BiglistFileReader
-ListView = Slicer
-ChainedList = Chain
-ParquetFileData = ParquetFileReader
+__version__ = "0.7.7"
