@@ -2,6 +2,8 @@ from __future__ import annotations
 
 import atexit
 import concurrent.futures
+import copy
+import functools
 import io
 import itertools
 import json
@@ -12,7 +14,8 @@ import string
 import threading
 import warnings
 import weakref
-from collections.abc import Iterable, Iterator
+import zlib
+from collections.abc import Iterable, Iterator, Sequence
 from concurrent.futures import Future, ThreadPoolExecutor
 from datetime import datetime
 from typing import (
@@ -22,17 +25,12 @@ from typing import (
 )
 from uuid import uuid4
 
+import orjson
 import pyarrow
-from upathlib.serializer import (
-    ByteSerializer,
-    OrjsonSerializer,
-    PickleSerializer,
-    ZOrjsonSerializer,
-    ZPickleSerializer,
-    ZstdOrjsonSerializer,
-    ZstdPickleSerializer,
-    _loads,
-)
+import zstandard
+from deprecation import deprecated
+from typing_extensions import Self
+from upathlib import serializer
 
 from ._base import (
     BiglistBase,
@@ -41,8 +39,9 @@ from ._base import (
     FileSeq,
     PathType,
     Upath,
+    resolve_path,
 )
-from ._util import lock_to_use
+from ._util import lock_to_use, make_parquet_schema
 
 logger = logging.getLogger(__name__)
 
@@ -85,8 +84,7 @@ class Biglist(BiglistBase[Element]):
     def register_storage_format(
         cls,
         name: str,
-        serializer: type[ByteSerializer],
-        overwrite: bool = False,
+        serializer: type[serializer.ByteSerializer],
     ) -> None:
         """
         Register a new serializer to handle data file dumping and loading.
@@ -101,26 +99,22 @@ class Biglist(BiglistBase[Element]):
 
             After registering the new serializer with name "xyz", one can use
             ``storage_format='xyz'`` in calls to ``new``.
-            When reading the object back from persistence.
+            When reading the object back from persistence,
             make sure this registry is also in place so that the correct
             deserializer can be found.
 
         serializer
             A subclass of `upathlib.serializer.ByteSerializer <https://github.com/zpz/upathlib/blob/main/src/upathlib/serializer.py>`_.
-
-        overwrite
-            Whether to overwrite an existent registrant by the same name.
         """
         good = string.ascii_letters + string.digits + "-_"
         assert all(n in good for n in name)
         if name.replace("_", "-") in cls.registered_storage_formats:
-            if not overwrite:
-                raise ValueError(f"serializer '{name}' is already registered")
+            raise ValueError(f"serializer '{name}' is already registered")
         name = name.replace("_", "-")
         cls.registered_storage_formats[name] = serializer
 
     @classmethod
-    def dump_data_file(cls, path: Upath, data: list[Element]) -> None:
+    def dump_data_file(cls, path: Upath, data: list[Element], **kwargs) -> None:
         """
         This method persists a batch of data elements, always a list,
         to disk or cloud storage.
@@ -135,6 +129,11 @@ class Biglist(BiglistBase[Element]):
         transformations for the user, it can customize :meth:`dump_data_file`
         and :meth:`load_data_file`.
 
+        Parameters
+        ----------
+        **kwargs
+            Additional keyword arguments to the serializer.
+
         See Also
         --------
         :meth:`load_data_file`
@@ -142,15 +141,20 @@ class Biglist(BiglistBase[Element]):
         serializer = cls.registered_storage_formats[
             path.suffix.lstrip(".").replace("_", "-")
         ]
-        path.write_bytes(serializer.serialize(data))
+        path.write_bytes(serializer.serialize(data, **kwargs))
 
     @classmethod
-    def load_data_file(cls, path: Upath) -> list[Element]:
+    def load_data_file(cls, path: Upath, **kwargs) -> list[Element]:
         """Load the data file given by ``path``.
 
         This function is used as the argument ``loader`` to :meth:`BiglistFileReader.__init__`.
         The value it returns is contained in :class:`FileReader` for subsequent use.
 
+        Parameters
+        ----------
+        **kwargs
+            Additional keyword arguments to the deserializer.
+
         See Also
         --------
         dump_data_file
@@ -159,7 +163,7 @@ class Biglist(BiglistBase[Element]):
             path.suffix.lstrip(".").replace("_", "-")
         ]
         data = path.read_bytes()
-        return deserializer.deserialize(data)
+        return deserializer.deserialize(data, **kwargs)
 
     @classmethod
     def new(
@@ -168,8 +172,11 @@ class Biglist(BiglistBase[Element]):
         *,
         batch_size: Optional[int] = None,
         storage_format: Optional[str] = None,
+        serialize_kwargs: Optional[dict] = None,
+        deserialize_kwargs: Optional[dict] = None,
+        init_info: dict = None,
         **kwargs,
-    ) -> Biglist:
+    ) -> Self:
         """
         Parameters
         ----------
@@ -216,11 +223,29 @@ class Biglist(BiglistBase[Element]):
 
             A rule of thumb: it is recommended to keep the persisted files between 32-128MB
             in size. (Note: no benchmark was performed to back this recommendation.)
-
         storage_format
             This should be a key in :data:`registered_storage_formats`.
             If not specified, :data:`DEFAULT_STORAGE_FORMAT` is used.
+        serialize_kwargs
+            Additional keyword arguments to the serialization function.
+        deserialize_kwargs
+            Additional keyword arguments to the deserialization function.
 
+            ``serialize_kwargs`` and ``deserialize_kwargs`` are rarely needed.
+            One use case is ``schema`` when storage format is "parquet".
+
+            ``serialize_kwargs`` and ``deserialize_kwargs``, if not ``None``,
+            will be saved in the "info.json" file, hence they must be JSON
+            serializable, meaning they need to be the few simple native Python
+            types that are supported by the standard ``json`` library.
+            (However, the few formats "natively" supported by Biglist may get special treatment
+            to relax this requirement.)
+            If this is not possible, there are two solutions:
+
+            1. Define a subclass of ``Biglist``. The subclass can customize the ``classmethod``\\s
+               :meth:`dump_data_file` and :meth:`load_data_file` to handle extra serialization options
+               internally.
+            2. Define a custom serialization class and register it with :meth:`register_storage_format`.
         **kwargs
             additional arguments are passed on to :meth:`BiglistBase.new`.
 
@@ -229,50 +254,76 @@ class Biglist(BiglistBase[Element]):
         Biglist
             A new :class:`Biglist` object.
         """
-        obj = super().new(path, **kwargs)  # type: ignore
-
         if not batch_size:
             batch_size = 10000
         else:
             assert batch_size > 0
-        obj.info["batch_size"] = batch_size
 
         if storage_format is None:
             storage_format = cls.DEFAULT_STORAGE_FORMAT
         if storage_format.replace("_", "-") not in cls.registered_storage_formats:
             raise ValueError(f"invalid value of `storage_format`: '{storage_format}'")
-        obj.info["storage_format"] = storage_format.replace("_", "-")
-        obj.info["storage_version"] = 2
-        # `storage_version` is a flag for certain breaking changes in the implementation,
-        # such that certain parts of the code (mainly concerning I/O) need to
-        # branch into different treatments according to the version.
-        # This has little relation to `storage_format`.
-        # version 0 designator introduced on 2022/3/8
-        # version 1 designator introduced on 2022/7/25
-        # version 2 designator introduced in version 0.7.4.
 
-        obj.info["data_files_info"] = []
-
-        obj._info_file.write_json(obj.info, overwrite=True)
+        init_info = {
+            **(init_info or {}),
+            "storage_format": storage_format.replace("_", "-"),
+            "storage_version": 3,
+            # `storage_version` is a flag for certain breaking changes in the implementation,
+            # such that certain parts of the code (mainly concerning I/O) need to
+            # branch into different treatments according to the version.
+            # This has little relation to `storage_format`.
+            # version 0 designator introduced on 2022/3/8
+            # version 1 designator introduced on 2022/7/25
+            # version 2 designator introduced in version 0.7.4.
+            # version 3 designator introduced in version 0.7.7.
+            "batch_size": batch_size,
+            "data_files_info": [],
+        }
+        if serialize_kwargs:
+            init_info["serialize_kwargs"] = serialize_kwargs
+        if deserialize_kwargs:
+            init_info["deserialize_kwargs"] = deserialize_kwargs
 
+        obj = super().new(path, init_info=init_info, **kwargs)  # type: ignore
         return obj
 
-    def __init__(self, *args, **kwargs):
-        """Please see doc of the base class."""
+    def __init__(
+        self,
+        *args,
+        **kwargs,
+    ):
+        """
+        Please see the base class for additional documentation.
+        """
         super().__init__(*args, **kwargs)
         self.keep_files: bool = True
         """Indicates whether the persisted files should be kept or deleted when the object is garbage-collected."""
 
         self._append_buffer: list = []
+        self._append_files_buffer: list = []
         self._file_dumper = None
         self._n_write_threads = 3
+        self._serialize_kwargs = self.info.get("serialize_kwargs", {})
+        self._deserialize_kwargs = self.info.get("deserialize_kwargs", {})
+        if self.storage_format == "parquet" and "schema_spec" in self._serialize_kwargs:
+            # Build the schema so that it does not need to be done each time the function
+            # ``ParquetSerializer.serialize`` is called. Maybe this does not matter.
+            assert "schema" not in self._serialize_kwargs
+            kk = copy.deepcopy(self._serialize_kwargs)
+            kk["schema"] = make_parquet_schema(kk["schema_spec"])
+            del kk["schema_spec"]
+            self._serialize_kwargs = kk
 
         _biglist_objs.add(self)
         self._flushed = True
 
         # For back compat.
-        if self.info:
-            # This is not called by ``new``, instead is opening an existing dataset
+        if self.info.get("storage_version", 0) < 3:
+            # This is not called by ``new``, instead is opening an existing dataset.
+            # Usually these legacy datasets are in a "read-only" mode, i.e., you should
+            # not append more data to them. If you do, the back-compat code below
+            # may not be totally reliable if the dataset is being used by multiple workers
+            # concurrently.
             if "data_files_info" not in self.info:  # added in 0.7.4
                 if self.storage_version == 0:
                     # This may not be totally reliable in every scenario.
@@ -286,8 +337,7 @@ class Biglist(BiglistBase[Element]):
                         # A list of tuples, (file_name, item_count)
                     except FileNotFoundError:
                         data_files = []
-                else:
-                    assert self.storage_version == 1
+                elif self.storage_version == 1:
                     # Starting with storage_version 1, data file name is
                     #   <timestamp>_<uuid>_<itemcount>.<ext>
                     # <timestamp> contains a '.', no '_';
@@ -309,6 +359,10 @@ class Biglist(BiglistBase[Element]):
                         ]  # file name, item count
                     else:
                         data_files = []
+                else:
+                    pass
+                    # `storage_version == 2 already has `data_files_info` in `self.info`,
+                    # but its format may be bad, hence it's included below.
 
                 if data_files:
                     data_files_cumlength = list(
@@ -329,18 +383,20 @@ class Biglist(BiglistBase[Element]):
                     ff.write_json(self.info, overwrite=True)
 
             else:
-                # added in 0.7.5: check for a bug introduced in 0.7.4
-                # convert full path to file name
+                # Added in 0.7.5: check for a bug introduced in 0.7.4.
+                # Convert full path to file name.
+                # Version 0.7.4 was used very briefly, hence very few datasets
+                # were created by that version.
                 data_files_info = self.info["data_files_info"]
                 if data_files_info:
                     new_info = None
                     if os.name == "nt" and "\\" in data_files_info[0][0]:
                         new_info = [
-                            (f[(f.rfind("\\") + 1):], *_) for f, *_ in data_files_info
+                            (f[(f.rfind("\\") + 1) :], *_) for f, *_ in data_files_info
                         ]
                     elif "/" in data_files_info[0][0]:
                         new_info = [
-                            (f[(f.rfind("/") + 1):], *_) for f, *_ in data_files_info
+                            (f[(f.rfind("/") + 1) :], *_) for f, *_ in data_files_info
                         ]
                     if new_info:
                         self.info["data_files_info"] = new_info
@@ -483,9 +539,11 @@ class Biglist(BiglistBase[Element]):
             self._file_dumper = Dumper(self._get_thread_pool(), self._n_write_threads)
         if wait:
             self._file_dumper.wait()
-            self.dump_data_file(data_file, buffer)
+            self.dump_data_file(data_file, buffer, **self._serialize_kwargs)
         else:
-            self._file_dumper.dump_file(self.dump_data_file, data_file, buffer)
+            self._file_dumper.dump_file(
+                self.dump_data_file, data_file, buffer, **self._serialize_kwargs
+            )
             # This call will return quickly if the dumper has queue
             # capacity for the file. The file meta data below
             # will be updated as if the saving has completed, although
@@ -496,15 +554,7 @@ class Biglist(BiglistBase[Element]):
             # what if dump fails later? The 'n_data_files' file is updated
             # already assuming everything will be fine.
 
-        if self.info["data_files_info"]:
-            n = self.info["data_files_info"][-1][-1]
-        else:
-            n = 0
-        self.info["data_files_info"].append((filename, buffer_len, n + buffer_len))
-        # This changes the ``info`` in this object only.
-        # When multiple workers are appending to the same big list concurrently,
-        # each of them will maintain their own ``info``. See ``flush`` for how
-        # they are merged and persisted.
+        self._append_files_buffer.append((filename, buffer_len))
 
     def flush(self) -> None:
         """
@@ -561,14 +611,14 @@ class Biglist(BiglistBase[Element]):
         # will get the final meta info right.
         with lock_to_use(self._info_file) as ff:
             z0 = ff.read_json()["data_files_info"]
-            z1 = self.info["data_files_info"]
-            z = sorted(set((*(tuple(v[:2]) for v in z0), *(tuple(v[:2]) for v in z1))))
+            z = sorted(set((*(tuple(v[:2]) for v in z0), *self._append_files_buffer)))
             # TODO: maybe a merge sort can be more efficient.
             cum = list(itertools.accumulate(v[1] for v in z))
             z = [(a, b, c) for (a, b), c in zip(z, cum)]
             self.info["data_files_info"] = z
             ff.write_json(self.info, overwrite=True)
 
+        self._append_files_buffer.clear()
         self._flushed = True
 
     def reload(self) -> None:
@@ -595,21 +645,35 @@ class Biglist(BiglistBase[Element]):
             warnings.warn(
                 f"did you forget to flush {self.__class__.__name__} at '{self.path}'?"
             )
+        if self._deserialize_kwargs:
+            fun = functools.partial(self.load_data_file, **self._deserialize_kwargs)
+        else:
+            fun = self.load_data_file
         return BiglistFileSeq(
             self.path,
             [
                 (str(self.data_path / row[0]), *row[1:])
                 for row in self.info["data_files_info"]
             ],
-            self.load_data_file,
+            fun,
         )
 
+    @deprecated(
+        deprecated_in="0.7.7",
+        removed_in="0.7.9",
+        details="Use ``Multiplexer`` instead.",
+    )
     def _multiplex_info_file(self, task_id: str) -> Upath:
         """
         `task_id`: returned by :meth:`new_multiplexer`.
         """
         return self.path / ".multiplexer" / task_id / "info.json"
 
+    @deprecated(
+        deprecated_in="0.7.7",
+        removed_in="0.7.9",
+        details="Use ``Multiplexer`` instead.",
+    )
     def new_multiplexer(self) -> str:
         """
         One worker, such as a "coordinator", calls this method once.
@@ -647,6 +711,11 @@ class Biglist(BiglistBase[Element]):
         )
         return task_id
 
+    @deprecated(
+        deprecated_in="0.7.7",
+        removed_in="0.7.9",
+        details="Use ``Multiplexer`` instead.",
+    )
     def multiplex_iter(
         self, task_id: str, worker_id: Optional[str] = None
     ) -> Iterator[Element]:
@@ -689,12 +758,22 @@ class Biglist(BiglistBase[Element]):
                 )
             yield self[n]
 
+    @deprecated(
+        deprecated_in="0.7.7",
+        removed_in="0.7.9",
+        details="Use ``Multiplexer`` instead.",
+    )
     def multiplex_stat(self, task_id: str) -> dict:
         """
         Return status info of an ongoing "multiplex iter".
         """
         return self._multiplex_info_file(task_id).read_json()
 
+    @deprecated(
+        deprecated_in="0.7.7",
+        removed_in="0.7.9",
+        details="Use ``Multiplexer`` instead.",
+    )
     def multiplex_done(self, task_id: str) -> bool:
         """Return whether the "multiplex iter" identified by ``task_id`` is finished."""
         ss = self.multiplex_stat(task_id)
@@ -726,7 +805,11 @@ class Dumper:
             raise t.exception()
 
     def dump_file(
-        self, file_dumper: Callable[[Upath, list], None], data_file: Upath, data: list
+        self,
+        file_dumper: Callable[[Upath, list], None],
+        data_file: Upath,
+        data: list,
+        **kwargs,
     ):
         """
         Parameters
@@ -749,7 +832,7 @@ class Dumper:
         # further actions of the `Biglist` and waiting for one file-dumping
         # to finish.
 
-        task = self._executor.submit(file_dumper, data_file, data)
+        task = self._executor.submit(file_dumper, data_file, data, **kwargs)
         self._tasks.add(task)
         task.add_done_callback(self._callback)
         # If task is already finished when this callback is being added,
@@ -833,19 +916,60 @@ class BiglistFileSeq(FileSeq[BiglistFileReader]):
         return BiglistFileReader(file, self._file_loader)
 
 
-class JsonByteSerializer(ByteSerializer):
+class JsonByteSerializer(serializer.ByteSerializer):
     @classmethod
     def serialize(cls, x, **kwargs):
         return json.dumps(x, **kwargs).encode()
 
     @classmethod
     def deserialize(cls, y, **kwargs):
-        return _loads(json.loads, y.decode(), **kwargs)
+        return serializer._loads(json.loads, y.decode(), **kwargs)
 
 
-class ParquetSerializer(ByteSerializer):
+class OrjsonSerializer(serializer.ByteSerializer):
     @classmethod
-    def serialize(cls, x: list[dict], schema=None, metadata=None, **kwargs):
+    def serialize(cls, x, **kwargs):
+        return orjson.dumps(x, **kwargs)  # pylint: disable=no-member
+
+    @classmethod
+    def deserialize(cls, y):
+        return serializer._loads(orjson.loads, y)  # pylint: disable=no-member
+
+
+class ZOrjsonSerializer(OrjsonSerializer):
+    @classmethod
+    def serialize(cls, x, *, level=serializer.ZLIB_LEVEL, **kwargs):
+        y = super().serialize(x, **kwargs)
+        return zlib.compress(y, level=level)
+
+    @classmethod
+    def deserialize(cls, y):
+        y = zlib.decompress(y)
+        return super().deserialize(y)
+
+
+class ZstdOrjsonSerializer(OrjsonSerializer):
+    @classmethod
+    def serialize(cls, x, *, level=serializer.ZSTD_LEVEL, **kwargs):
+        y = super().serialize(x, **kwargs)
+        return zstandard.compress(y, level=level)
+
+    @classmethod
+    def deserialize(cls, y):
+        y = zstandard.decompress(y)
+        return super().deserialize(y)
+
+
+class ParquetSerializer(serializer.ByteSerializer):
+    @classmethod
+    def serialize(
+        cls,
+        x: list[dict],
+        schema: pyarrow.Schema = None,
+        schema_spec: Sequence = None,
+        metadata=None,
+        **kwargs,
+    ):
         """
         `x` is a list of data items. Each item is a dict. In the output Parquet file,
         each item is a "row".
@@ -853,16 +977,30 @@ class ParquetSerializer(ByteSerializer):
         The content of the item dict should follow a regular pattern.
         Not every structure is supported. The data `x` must be acceptable to
         ``pyarrow.Table.from_pylist``. If unsure, use a list with a couple data elements
-        and experiment with ``pyarrow.Table.from_pylist`` directly, leaving out
-        ``schema`` and ``metadata``.
+        and experiment with ``pyarrow.Table.from_pylist`` directly.
 
         When using ``storage_format='parquet'`` for ``Biglist``, each data element is a dict
         with a consistent structure that is acceptable to ``pyarrow.Table.from_pylist``.
         When reading the Biglist, the original Python data elements are returned.
+        (A record read out may not be exactly equal to the original that was written, in that
+        elements that were missing in a record when written may have been filled in with ``None``
+        when read back out.)
         In other words, the reading is *not* like that of ``ParquetBiglist``.
         You can always create a separate ParquetBiglist for the data files of the Biglist
         in order to use Parquet-style data reading. The data files are valid Parquet files.
+
+        If neither ``schema`` nor ``schema_spec`` is specified, then the data schema is auto-inferred
+        based on the first element of ``x``. If this does not work, you can specify either ``schema`` or ``schema_spec``.
+        The advantage of ``schema_spec`` is that it is json-serializable Python types, hence can be passed into
+        :meth:`Biglist.new() <biglist.Biglist.new>` via ``serialize_kwargs`` and saved in "info.json" of the biglist.
+
+        If ``schema_spec`` is not flexible or powerful enough for your usecase, then you may have to use ``schema``.
         """
+        if schema is not None:
+            assert schema_spec is None
+        elif schema_spec is not None:
+            assert schema is None
+            schema = make_parquet_schema(schema_spec)
         table = pyarrow.Table.from_pylist(x, schema=schema, metadata=metadata)
         sink = io.BytesIO()
         writer = pyarrow.parquet.ParquetWriter(sink, table.schema, **kwargs)
@@ -878,10 +1016,209 @@ class ParquetSerializer(ByteSerializer):
 
 
 Biglist.register_storage_format("json", JsonByteSerializer)
-Biglist.register_storage_format("pickle", PickleSerializer)
-Biglist.register_storage_format("pickle-z", ZPickleSerializer)
-Biglist.register_storage_format("pickle-zstd", ZstdPickleSerializer)
+Biglist.register_storage_format("pickle", serializer.PickleSerializer)
+Biglist.register_storage_format("pickle-z", serializer.ZPickleSerializer)
+Biglist.register_storage_format("pickle-zstd", serializer.ZstdPickleSerializer)
 Biglist.register_storage_format("orjson", OrjsonSerializer)
 Biglist.register_storage_format("orjson-z", ZOrjsonSerializer)
 Biglist.register_storage_format("orjson-zstd", ZstdOrjsonSerializer)
 Biglist.register_storage_format("parquet", ParquetSerializer)
+
+
+class Multiplexer:
+    """
+    Multiplexer is used to distribute data elements to multiple "workers" so that
+    each element is obtained by exactly one worker.
+
+    Typically, the data element is small in size but requires significant time to process
+    by the worker. The data elements are "hyper parameters".
+
+    The usage consists of two main parts:
+
+    1. In "controller" code, call :meth:`start` to start a new "session".
+        Different sessions (at the same time or otherwise) are independent consumers of the data.
+    2. In "worker" code, use the session ID that was returned by :meth:`start` to instantiate
+        a Multiplexer and iterate over it. In so doing, multiple workers will obtain the data elements
+        collectively, i.e., each element is obtained by exactly one worker.
+    """
+
+    @classmethod
+    def new(
+        cls,
+        data: Iterable[Any],
+        path: Optional[PathType],
+        *,
+        batch_size: int = 10_000,
+        storage_format: Optional[str] = None,
+    ):
+        """
+        Parameters
+        ----------
+        data
+            The data elements that need to be distributed. The elements should be pickle-able.
+        path
+            A non-existent directory where the data and any supporting info will be saved.
+
+            If ``path`` is in the cloud, then the workers can be on multiple machines, and in multiple threads
+            or processes on each machine.
+            If ``path`` is on the local disk, then the workers are in threads or processes on the same machine.
+
+            However, there are no strong reasons to use this facility on a local machine.
+
+            Usually this class is used to distribute data to a cluster of machines, hence
+            this path points to a location in a cloud storage that is supported by ``upathlib``.
+        """
+        path = resolve_path(path)
+        bl = Biglist.new(
+            path / "data", batch_size=batch_size, storage_format=storage_format
+        )
+        bl.extend(data)
+        bl.flush()
+        assert len(bl) > 0
+        return cls(path)
+
+    def __init__(
+        self,
+        path: PathType,
+        task_id: Optional[str] = None,
+        worker_id: Optional[str] = None,
+    ):
+        """
+        Create a Multiplexer object and use it to distribute the data elements that have been
+        stored by :meth:`new`.
+
+        Parameters
+        ----------
+        path
+            The directory where data is stored. This is the ``path`` that was passed to :meth:`new`.
+        task_id
+            A string that was returned by :meth:`start` on another instance
+            of this class with the same ``path`` parameter.
+        worker_id
+            A string representing a particular worker.
+            This is meaningful only if ``task_id`` is provided.
+            If ``task_id`` is provided but ``worker_id`` is missing,
+            a default is constructed based on thread name and process name.
+        """
+        if task_id is None:
+            assert worker_id is None
+        self.path = path
+        self._task_id = task_id
+        self._worker_id = worker_id
+        self._data = None
+
+    @property
+    def data(self) -> Biglist:
+        """
+        Return the data elements stored in this Multiplexer.
+        """
+        if self._data is None:
+            self._data = Biglist(self.path / "data")
+        return self._data
+
+    def __len__(self) -> int:
+        """
+        Return the number of data elements stored in this Multiplexer.
+        """
+        return len(self.data)
+
+    def _mux_info_file(self, task_id: str) -> Upath:
+        """
+        `task_id`: returned by :meth:`start`.
+        """
+        return self.path / ".mux" / task_id / "info.json"
+
+    def start(self) -> str:
+        """
+        One worker, such as a "coordinator", calls this method once.
+        After that, one or more workers independently
+        iterate over a :class:`Multiplexer` object with the task-ID returned by
+        this method. The data that was provided to :meth:`new` is
+        split between the workers in that each data element will be obtained
+        by exactly one worker.
+
+        In order to call this method, the object should have been initiated without
+        ``task_id`` or ``worker_id``.
+
+        The returned value is the argument ``task_id`` to be provided to :meth:`__init__`
+        in worker code.
+        """
+        assert not self._task_id
+        assert not self._worker_id
+        task_id = datetime.utcnow().isoformat()
+        self._mux_info_file(task_id).write_json(
+            {
+                "total": len(self.data),
+                "next": 0,
+                "time": datetime.utcnow().isoformat(),
+            },
+            overwrite=False,
+        )
+        self._task_id = task_id
+        # Usually the object that called ``start`` will not be used by a worker
+        # to iterate over the data. The task-id is stored on the object
+        # mainly to enable this "controller" to call ``stat`` later.
+        return task_id
+
+    def __iter__(self) -> Iterator[Element]:
+        """
+        Worker iterates over the data contained in the Multiplexer.
+
+        In order to call this method, ``task_id`` must have been provided
+        to :meth:`__init__`.
+        """
+        assert self._task_id
+        if not self._worker_id:
+            self._worker_id = "{} {}".format(
+                multiprocessing.current_process().name,
+                threading.current_thread().name,
+            )
+        worker_id = self._worker_id
+        finfo = self._mux_info_file(self._task_id)
+        while True:
+            with lock_to_use(finfo) as ff:
+                # In concurrent use cases, I've observed
+                # `upathlib.LockAcquireError` raised here.
+                # User may want to do retry here.
+                ss = ff.read_json()
+                # In concurrent use cases, I've observed
+                # `FileNotFoundError` here. User may want
+                # to do retry here.
+
+                n = ss["next"]
+                if n == ss["total"]:
+                    return
+                ff.write_json(
+                    {
+                        "next": n + 1,
+                        "worker_id": worker_id,
+                        "time": datetime.utcnow().isoformat(),
+                        "total": ss["total"],
+                    },
+                    overwrite=True,
+                )
+            yield self.data[n]
+
+    def stat(self) -> dict:
+        """
+        Return status info of an ongoing iteration.
+        """
+        assert self._task_id
+        return self._mux_info_file(self._task_id).read_json()
+
+    def done(self) -> bool:
+        """
+        Return whether the data iteration is finished.
+
+        This is often called in the "controller" code on the object
+        that has had its :meth:`start` called.
+        """
+        ss = self.stat()
+        return ss["next"] == ss["total"]
+
+    def destroy(self) -> None:
+        """
+        Delete all the data stored by this Multiplexer, hence reclaiming the storage space.
+        """
+        self.data.destroy()
+        self.path.rmrf()
