@@ -2,17 +2,13 @@ from __future__ import annotations
 
 import itertools
 import logging
-import warnings
-from collections.abc import Iterable, Iterator, Sequence
-from concurrent.futures import ThreadPoolExecutor
+from collections.abc import Iterator, Sequence
 from pathlib import Path
 from typing import Any, Callable, Optional
 
 import pyarrow
-from deprecation import deprecated
 from pyarrow.fs import FileSystem, GcsFileSystem
 from pyarrow.parquet import FileMetaData, ParquetFile
-from upathlib import LocalUpath
 
 from ._base import (
     BiglistBase,
@@ -22,10 +18,9 @@ from ._base import (
     Seq,
     Upath,
     _get_global_thread_pool,
-    _unspecified,
     resolve_path,
 )
-from ._util import Slicer, locate_idx_in_chunked_seq, lock_to_use
+from ._util import locate_idx_in_chunked_seq, lock_to_use
 
 # If data is in Google Cloud Storage, `pyarrow.fs.GcsFileSystem` accepts "access_token"
 # and "credential_token_expiration". These can be obtained via
@@ -97,7 +92,6 @@ class ParquetBiglist(BiglistBase):
         path: Optional[PathType] = None,
         *,
         suffix: str = ".parquet",
-        thread_pool_executor: Optional[ThreadPoolExecutor] = _unspecified,
         **kwargs,
     ) -> ParquetBiglist:
         """
@@ -133,11 +127,6 @@ class ParquetBiglist(BiglistBase):
                 directory, the files therein (recursively) are sorted by the string
                 value of each file's full path.
 
-        thread_pool_executor
-
-            .. deprecated:: 0.7.4
-                The input is ignored. Will be removed in 0.7.6.
-
         suffix
             Only files with this suffix will be included.
             To include all files, use ``suffix='*'``.
@@ -145,13 +134,6 @@ class ParquetBiglist(BiglistBase):
         **kwargs
             additional arguments are passed on to ``__init__``.
         """
-        if thread_pool_executor is not _unspecified:
-            warnings.warn(
-                "`thread_pool_executor` is deprecated and ignored; will be removed in 0.7.6",
-                DeprecationWarning,
-                stacklevel=2,
-            )
-
         if isinstance(data_path, (str, Path, Upath)):
             #  TODO: in py 3.10, we will be able to do `isinstance(data_path, PathType)`
             data_path = [resolve_path(data_path)]
@@ -734,14 +716,6 @@ class ParquetBatchData(Seq):
         """
         return self._data.column(idx_or_name)
 
-    @deprecated(
-        deprecated_in="0.7.4",
-        removed_in="0.7.6",
-        details="Use ``Slicer`` instead.",
-    )
-    def view(self):
-        return Slicer(self)
-
 
 def read_parquet_file(path: PathType) -> ParquetFileReader:
     """
@@ -751,46 +725,3 @@ def read_parquet_file(path: PathType) -> ParquetFileReader:
         Path of the file.
     """
     return ParquetFileReader(path, ParquetBiglist.load_data_file)
-
-
-def write_parquet_file(
-    path: PathType,
-    data: pyarrow.Table | Sequence[pyarrow.Array | pyarrow.ChunkedArray | Iterable],
-    *,
-    names: Optional[Sequence[str]] = None,
-    **kwargs,
-) -> None:
-    """
-    If the file already exists, it will be overwritten.
-
-    Parameters
-    ----------
-    path
-        Path of the file to create and write to.
-    data
-        Usually a list of data arrays.
-    names
-        List of names for the arrays in ``data``.
-    **kwargs
-        Passed on to `pyarrow.parquet.write_table() <https://arrow.apache.org/docs/python/generated/pyarrow.parquet.write_table.html>`_.
-    """
-    if not isinstance(data, pyarrow.Table):
-        assert names
-        assert len(names) == len(data)
-        arrays = [
-            a
-            if isinstance(a, (pyarrow.Array, pyarrow.ChunkedArray))
-            else pyarrow.array(a)
-            for a in data
-        ]
-        data = pyarrow.Table.from_arrays(arrays, names=names)
-    else:
-        assert names is None
-    path = resolve_path(path)
-    if isinstance(path, LocalUpath):
-        path.parent.path.mkdir(exist_ok=True, parents=True)
-
-    ff, pp = FileSystem.from_uri(str(path))
-    if isinstance(ff, GcsFileSystem):
-        ff = ParquetBiglist.get_gcsfs()
-    pyarrow.parquet.write_table(data, ff.open_output_stream(pp), **kwargs)
